---
layout: post
title: "Hello World!"
date: 2012-11-25 14:07
slug: hello-world
categories: linux
description: [root@linux115 spool]# service postfix start启动 postfix： [失败]
---

Welcome to Crotal, This is the first post, modify or remove it, and start your own blog!

Write you post like this:

```
---
title: "Hello, World"
date: 2013-04-20 15:10
categories: crotal
slug: hello-world
---

Welcome to Crotal, This is your first post, modify or remove it, and start your own blog!
```

Add a picture like this:

```markdown
![octocat](/images/Octocat.jpg)
```

![octocat](/images/Octocat.jpg)

Check the <a href="http://crotal.org/docs/" target="_blank">documents</a> for more information.
